package wildCaves;

import java.util.List;
import java.util.Random;

import cpw.mods.fml.relauncher.Side;
import cpw.mods.fml.relauncher.SideOnly;
import net.minecraft.block.Block;
import net.minecraft.block.material.Material;
import net.minecraft.client.renderer.texture.IconRegister;
import net.minecraft.creativetab.CreativeTabs;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.util.Icon;
import net.minecraft.world.IBlockAccess;
import net.minecraft.world.World;

public class BlockFossils extends Block
{
	@SideOnly(Side.CLIENT)
	private Icon[] iconArray;
	private int numOfStructures=1;

	public BlockFossils(int id)
	{
		super(id, Material.rock);
		this.setHardness(1F);
		this.setCreativeTab(WildCaves.tabWildCaves);
        setUnlocalizedName("fossilsBlock");
        this.setStepSound(soundStoneFootstep);
	}
	
	@Override
    public int idDropped(int metadata, Random random, int par3)
    {
		int choise = Utils.weightedChoise(0.5f, 0.15f, 0.05f, 0.5f, 0, 0);
		int result = 0;
			switch(choise)
			{
				case 1: 
					result=Item.bone.itemID;
					break;
				case 2: 
					result=Item.arrow.itemID;
					break;
				case 3: 
					result=Item.skull.itemID;
					break;
				case 4:
					result=Block.cobblestone.blockID;
			}
		return result;
    }
    
	@Override
    public int quantityDropped(Random rand)
    {
        return 1;
    }
    
    @Override
	public int damageDropped (int metadata) 
    {
		return 0;
	}
    
    @Override
    @SideOnly(Side.CLIENT)
    public Icon getIcon(int side, int metadata)
    {
    	if(metadata >= numOfStructures)
    		metadata = numOfStructures-1;
        return this.iconArray[metadata];
    }
    
    /**
     * Get the block's damage value (for use with pick block).
     */
    @Override
    public int getDamageValue(World world, int x, int y, int z)
    {
        return world.getBlockMetadata(x, y, z);
    }
    
    @Override
    public boolean canSilkHarvest(World world, EntityPlayer player, int x, int y, int z, int metadata)
    {
    	return true;
    }
    
    @SideOnly(Side.CLIENT)
    public void getSubBlocks(int par1, CreativeTabs par2CreativeTabs, List par3List)
    {
        for (int i = 0; i < numOfStructures; ++i)
        {
            par3List.add(new ItemStack(par1, 1, i));
        }
    }
    
    @Override
    @SideOnly(Side.CLIENT)
    public Icon getBlockTexture(IBlockAccess blockAccess, int x, int y, int z, int side)
    {
    	return this.iconArray[blockAccess.getBlockMetadata(x, y, z)];
    }

	@Override
	@SideOnly(Side.CLIENT)
	public void registerIcons(IconRegister iconRegister) 
	{
        this.iconArray = new Icon[numOfStructures];

        for (int i = 0; i < this.iconArray.length; ++i)
        {
            this.iconArray[i] = iconRegister.registerIcon(WildCaves.modid + ":fossils"+ i);
        }
	}
}
